All Classes and Interfaces

Class
Description
 
 
Auto-configuration for ComponentFlow.
 
Callback interface that can be used to customize a ComponentFlow.Builder.
Shell implementation using JLine to capture input and trigger completions.
 
 
 
Creates supporting beans for running the Shell.
Configuration properties for Spring Shell.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Sets up all required beans for supporting the standard Shell API.
Creates beans for standard commands.
Callback interface that can be used to customize a Terminal via its TerminalBuilder.